# pymultiplayer
A package for adding multiplayer functionality to games.

# NOTE
This is a work in progress. Don't expect all features to work.
I don't know what version of python is needed for this package to work.
I will figure this stuff out in due course
This is mainly just a passion project/project to help future projects but it would be nice if it had some use.

